@@ -146,6 +146,7 @@ static gboolean validity_check (              GtkTreeModel *model,
         gtk_tree_model_get (model, iter, TS_VALUE, &value, -1);
         if (G_UNLIKELY ((new_value = compute_hypothetical_replacement (value)) && 
                         !streq_any (new_value, "yes", "no", NULL))) {
+			// Translation note: Do not translate "enabled", "yes", "no"
             g_autofree gchar *err_msg = g_strdup_printf (_("An <b>\"enabled\"</b> option can't have a value other than "
                                                            "<b>\"yes\"</b> or <b>\"no\"</b> and thus a replacement of "
                                                            "\"%s\" with \"%s\" won't be done.\n\n"
@@ -292,6 +293,7 @@ static gboolean validity_check (              GtkTreeModel *model,
 
                 gtk_tree_model_get (model, iter, TS_MENU_ID, &menu_id_txt, -1);
 
+                // Translation note: Do not translate "execute"
                 g_autofree gchar *err_msg = g_strdup_printf (_("The execute instruction of the pipe menu <b>\"%1$s\"</b> "
                                                                "with the menu ID <b>\"%2$s\"</b> won't be deleted, "
                                                                "because this would render this pipe menu useless.\n\n"
@@ -503,7 +505,9 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
 
         replacements_done_label_txt = (fr_data.replacements_done_cnt) ? 
                                       ((fr_data.replacements_done_cnt < 10) ? 
+									   // Translation note: The translation should work for %s getting replaced with phrases ranging from "once" to "nine times"
                                        g_strdup_printf (_("Search key replaced %s."), _(small_numbers_spelled_out[(fr_data.replacements_done_cnt) - 1])) : 
+									   // Translation note: The translation should work for %i getting replaced with positive numbers
                                        g_strdup_printf (ngettext ("Search key replaced %i times.", "Search key replaced %i times.", fr_data.replacements_done_cnt), fr_data.replacements_done_cnt)) : 
                                        g_strdup (_("Search key not found."));
         gtk_label_set_text (GTK_LABEL (ks.fr_replacements_done_label), replacements_done_label_txt);
@@ -555,9 +559,17 @@ void show_find_and_replace_dialog (void)
     GtkWidget *columns_grid = gtk_grid_new ();
     GtkWidget *special_options_grid = gtk_grid_new ();
     enum { FR_REPLACE_LABEL, FR_IN_LABEL, FR_WITH_LABEL, NUMBER_OF_FR_LABEL_FIELDS };
-    const gchar *fr_label_txts[] = { _("<b>Replace: </b>"), _("<b>In:</b>"), _("<b>With:</b>") };
+    const gchar *fr_label_txts[] = { // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
+	                                 _("<b>Replace: </b>"), 
+									 // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
+									 _("<b>In:</b>"), 
+									 // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
+									 _("<b>With:</b>") };
     GtkWidget *fr_labels[NUMBER_OF_FR_LABEL_FIELDS] = { gtk_label_new (NULL), gtk_label_new (NULL), gtk_label_new (NULL) };
-    const gchar *special_options_txts[] = { _("Match Case"), _("Regular Expression (PCRE)"), _("Whole Word") };
+    const gchar *special_options_txts[] = { // This is for a search functionality. A translation of "case sensitive" or "distinguish between uppercase and lowercase letters" would also work.
+	                                        _("Match Case"), 
+	                                        _("Regular Expression (PCRE)"), 
+											_("Whole Word") };
 
     gint8 columns_cnt;
 
